***************
Release History
***************

.. Changelog entries should follow this format:

   version (release date)
   ======================

   **section**

   - One-line description of change (link to Github issue/PR)

.. Changes should be organized in one of several sections:

   - API changes
   - Improvements
   - Behavioural changes
   - Bugfixes
   - Documentation

0.1.2 (June 9, 2015)
====================

- Fixed a Python 3 compatibility issue with semantic pointer graphs.

0.1.1 (June 8, 2015)
====================

- A large number of stability and user experience fixes.
  The first release was a bit buggy, but this should be pretty stable.
- Includes many more examples out of the box.

0.1.0 (June 5, 2015)
====================

Initial release of Nengo GUI!
Thanks to all of the contributors for making this possible!
